/*
 * Newt-Puzzle
 * Copyright (C) Aude Jaulent 2008, 2009 <elderme@tuxfamily.org>
 * 
 * Newt-Puzzle is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Newt-Puzzle is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _KEYBOARDOPTIONS_H_
#define _KEYBOARDOPTIONS_H_


#include <map>
#include <SDL/SDL.h>

#include "fileManager.h"
#include "fileUtil.h"
#include "stringUtil.h"

	
		
struct KeyMap{
	SDLKey key;
	std::string name;
};

static KeyMap keymap[] = {
	{SDLK_BACKSPACE,"backspace"},
	{SDLK_TAB,"tab"},
	{SDLK_CLEAR,"clear"},
	{SDLK_RETURN,"return"},
	{SDLK_PAUSE,"pause"},
	{SDLK_ESCAPE,"escape"},
	{SDLK_SPACE,"space"},
	{SDLK_EXCLAIM,"!"},
	{SDLK_QUOTEDBL,"\""},
	{SDLK_HASH,"#"},
	{SDLK_DOLLAR,"$"},
	{SDLK_AMPERSAND,"&"},
	{SDLK_QUOTE,"'"},
	{SDLK_LEFTPAREN,"("},
	{SDLK_RIGHTPAREN,")"},
	{SDLK_ASTERISK,"*"},
	{SDLK_PLUS,"+"},
	{SDLK_COMMA,","},
	{SDLK_MINUS,"-"},
	{SDLK_PERIOD,"."},
	{SDLK_SLASH,"/"},
	{SDLK_0,"0"},
	{SDLK_1,"1"},
	{SDLK_2,"2"},
	{SDLK_3,"3"},
	{SDLK_4,"4"},
	{SDLK_5,"5"},
	{SDLK_6,"6"},
	{SDLK_7,"7"},
	{SDLK_8,"8"},
	{SDLK_9,"9"},
	{SDLK_COLON,":"},
	{SDLK_SEMICOLON,";"},
	{SDLK_LESS,"<"},
	{SDLK_EQUALS,"="},
	{SDLK_GREATER,">"},
	{SDLK_QUESTION,"?"},
	{SDLK_AT,"@"},
	
	{SDLK_LEFTBRACKET,"("},
	{SDLK_BACKSLASH,"\\"},
	{SDLK_RIGHTBRACKET,")"},
	{SDLK_CARET,"^"},
	{SDLK_UNDERSCORE,"_"},
	{SDLK_BACKQUOTE,"`"},
	
	{SDLK_DELETE,"del"},
	
	{SDLK_LEFT,"left"},
	{SDLK_RIGHT,"right"},
	{SDLK_UP,"up"},
	{SDLK_DOWN,"down"},
	{SDLK_KP0,"keypad 0"},
	{SDLK_KP1,"keypad 1"},
	{SDLK_KP2,"keypad 2"},
	{SDLK_KP3,"keypad 3"},
	{SDLK_KP4,"keypad 4"},
	{SDLK_KP5,"keypad 5"},
	{SDLK_KP6,"keypad 6"},
	{SDLK_KP7,"keypad 7"},
	{SDLK_KP8,"keypad 8"},
	{SDLK_KP9,"keypad 9"},
	{SDLK_KP_PERIOD,"keypad ."},
	{SDLK_KP_DIVIDE,"keypad /"},
	{SDLK_KP_MULTIPLY,"keypad *"},
	{SDLK_KP_MINUS,"keypad m"},
	{SDLK_KP_PLUS,"keypad +"},
	{SDLK_KP_ENTER,"keypad enter"},
	{SDLK_KP_EQUALS,"keypad ="},
	
	{SDLK_INSERT,"insert"},
	{SDLK_HOME,"home"},
	{SDLK_END,"end"},
	{SDLK_PAGEUP,"pageup"},
	{SDLK_PAGEDOWN,"pagedown"},
    
	{SDLK_F1,"F1"},
	{SDLK_F2,"F2"},
	{SDLK_F3,"F3"},
	{SDLK_F4,"F4"},
	{SDLK_F5,"F5"},
	{SDLK_F6,"F6"},
	{SDLK_F7,"F7"},
	{SDLK_F8,"F8"},
	{SDLK_F9,"F9"},
	{SDLK_F10,"F10"},
	{SDLK_F11,"F11"},
	{SDLK_F12,"F12"},
	{SDLK_F13,"F13"},
	{SDLK_F14,"F14"},
	{SDLK_F15,"F15"},
    
	{SDLK_NUMLOCK,"num lock"},
	{SDLK_CAPSLOCK,"caps lock"},
	{SDLK_SCROLLOCK,"scroll lock"},
	{SDLK_RSHIFT,"right shift"},
	{SDLK_LSHIFT,"left shift"},
	{SDLK_RCTRL,"right ctrl"},
	{SDLK_LCTRL,"left ctrl"},
	{SDLK_RALT,"right alt"},
	{SDLK_LALT,"left alt"},
	{SDLK_RMETA,"right meta"},
	{SDLK_LMETA,"left meta"},
	{SDLK_LSUPER,"left super"}, /* Left "Windows" key */
	{SDLK_RSUPER,"right super"}, /* Right "Windows" key */
	{SDLK_MODE,"alt gr"}, /* "Alt Gr" key */
	{SDLK_COMPOSE,"compose"}, /* Multi-key compose key */	
};




class KeyboardOptions
{
public:
	KeyboardOptions(std::string fileName, KeyMap defaultsKeys[], int nbKeys);
	virtual ~KeyboardOptions();
		
	void setDefaultParameters();
				
	void readConfigurationFile();
	virtual void writeConfigurationFile() = 0;
	
	std::string SDLKeyToString(SDLKey key);
	SDLKey StringToSDLKey(std::string keyString);	
		
	SDLKey getKey(std::string name);
				
		
protected:
	std::string mFileName;
	std::map<std::string, int> keys;
	KeyMap *mDefaultsKeys;
	int mNbKeys;

	std::string writeParam(std::string name, std::vector<std::string> comments) ;
		
};


class GeneralKeyboardOptions: public KeyboardOptions
{
public:
	GeneralKeyboardOptions();
	~GeneralKeyboardOptions();
	
	void writeConfigurationFile();	
	
};


extern GeneralKeyboardOptions *generalKeyboardOptions;


#endif // _KEYBOARDOPTIONS_H_
