/*
 * Newt-Puzzle
 * Copyright (C) Aude Jaulent 2009 <elderme@tuxfamily.org>
 * 
 * Newt-Puzzle is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Newt-Puzzle is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "skyShader.h"


SkyShader::SkyShader() : Shader() {
	std::vector<std::string> vsFiles, fsFiles;
	
	vsFiles.push_back("sky.vert");
	fsFiles.push_back("sky.frag");	
	
	id = loadProgram(vsFiles,fsFiles);
	
	if(id == 0) {
		std::cerr << "The sky shader cannot be loaded." << std::endl;
	} else {
		locationSunDirection = glGetUniformLocation(id, "sunDirection");	
		locationSkyMap = glGetUniformLocation(id, "skyMap");	
		locationSkyNightMap = glGetUniformLocation(id, "skyNightMap");	
	}		
}

void SkyShader::setTexId(int id, int idNight) {
	glUniform1i	(locationSkyMap, id);	
	glUniform1i	(locationSkyNightMap, idNight);		
}

void SkyShader::setSunDirection(Vector3 sunDirection) {
	glUniform3fv(locationSunDirection, 3, sunDirection);		
}

int SkyShader::getLocationSunDirection() {
	return locationSunDirection;
}



