/*
 * Newt-Puzzle
 * Copyright (C) Aude Jaulent 2009 <elderme@tuxfamily.org>
 * 
 * Newt-Puzzle is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Newt-Puzzle is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "rectanglePrism.h"
#include "../newtEngine/scene.h"


RectanglePrismMesh::RectanglePrismMesh(float dim1, int nb1, float dim2, int nb2, float height, int nbH, float edgeRadius, int nbR, 
									   baseType base1, baseType base2, bool inside):
	Mesh("rectangularPrism", false, true, false, true), 
	mDim1(dim1), mDim2(dim2), mHeight(height), mEdgeRadius(edgeRadius), mNb1(nb1), mNb2(nb2), mBase1(base1), mBase2(base2), mInside(inside)
{

	float meshLevel = scene->getGraphicOptions()->getMeshLevel();
	float value;
	
	value = (float) mNbR * meshLevel;
	if(value < 2) {
		mNbR = 2;
	} else {
		mNbR = (int) value;
	}	
}

RectanglePrismMesh::~RectanglePrismMesh() {
	
}

void RectanglePrismMesh::initFirstParams() {
	geometry.nbVertices = (mNbH + 1) * ( 4*mNbR + 2*(mNb1+mNb2));
	geometry.nbIndexArrays = mNbH ;
	
	switch(mBase1) {
		case BASE_FLAT:
			geometry.nbVertices += 4*mNbR*mNbR + 2*(mNb1+mNb2)*mNbR;
			geometry.nbIndexArrays += mNbR;		
			break;
		
		case BASE_FLAT2:
	
			break;
		
	}
	
	switch(mBase2) {
		case BASE_FLAT:
			geometry.nbVertices += 4*mNbR*mNbR + 2*(mNb1+mNb2)*mNbR;
			geometry.nbIndexArrays += mNbR;				
			break;
		
		
		case BASE_FLAT2:
			
			break;
	}	
	
	geometry.primType = new GLenum[geometry.nbIndexArrays];
	geometry.nbIndices = new int[geometry.nbIndexArrays];
	
	
	for(int i=0;i<geometry.nbIndexArrays;i++) {
		geometry.primType[i] = GL_QUAD_STRIP;
	}
	
	for(int i=0;i<geometry.nbIndexArrays;i++) {
		geometry.nbIndices[i] = 2 * (4*mNbR + 2*(mNb1+mNb2) + 1);
	}	
	
	switch(mBase1) {
		case BASE_FLAT:
			geometry.primType[0] = GL_TRIANGLES;
			geometry.nbIndices[0] = 3*(4*mNbR + 4*(mNb1+mNb2));
			break;
		
		case BASE_FLAT2:
	
			break;
	}
	
	switch(mBase2) {
		case BASE_FLAT:
			geometry.primType[geometry.nbIndexArrays-1] = GL_TRIANGLES;
			geometry.nbIndices[geometry.nbIndexArrays-1] = 3*(4*mNbR + 4*(mNb1+mNb2));
			break;
		
		case BASE_FLAT2:
				
			break;
	}	
}				
		
void RectanglePrismMesh::createVertices(Vector3 *ptr) {
	
	if(mBase1 == BASE_FLAT) {
		//for(int i=0;i	
	}
	
}

void RectanglePrismMesh::createColors(Color *ptr) {
	
}

void RectanglePrismMesh::createNormals(Vector3 *ptr) {
	
}

void RectanglePrismMesh::createTexCoords(GLfloat *ptr) {
	
}

void RectanglePrismMesh::createFogCoords(GLfloat *ptr) {
	
}

void RectanglePrismMesh::createTangents(Vector3 *ptr) {
	
}
		
	
void RectanglePrismMesh::createIndices(int numArray, GLuint *ptr) {
	
}







